import 'package:customizable_counter/customizable_counter.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:group_radio_button/group_radio_button.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:realm/realm.dart';
import 'package:shop_app/helper/storage_helper.dart';
import 'package:syncfusion_flutter_sliders/sliders.dart';

class SettingConfigScreen extends StatefulWidget {
  static String routeName = "/setting_config";

  SettingConfigScreen({super.key});

  @override
  State<SettingConfigScreen> createState() => _SettingConfigScreenState();
}

class _SettingConfigScreenState extends State<SettingConfigScreen> {
  final _memberIdController = TextEditingController();
  final _ssoIdController = TextEditingController();

  final _minController = TextEditingController();
  final _maxController = TextEditingController();

  List<String> _collectionTypeList = ["Event", "Rotation"];
  List<String> _consentList = ["n/a**", "True", "False"];
  List<String> _maidList = ["True", "False"];

  // mark:RabbitDataInstance
  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');

  String collectionType = '';
  String consent = "n/a**";
  String maid = "False";
  bool deleteAfterSent = false;
  bool offlineMode = false;

  int retry = 0;
  int retentionDays = 0;
  int rotationTime = 0;
  int sessionExpire = 0;
  int sessionAutoExpire = 0;

  int cpu = 0;
  int memory = 0;
  int bettery = 0;

  @override
  void initState() {
    _memberIdController.text = rabbitData.userInfo.memberId;
    _ssoIdController.text = rabbitData.userInfo.ssoId;

    collectionType = rabbitData.config.collectionType.capitalizeFirst!;

    var consentVal = rabbitData.config.consent;

    consent = consentVal == null
        ? 'n/a**'
        : consentVal
            ? 'True'
            : 'False';

    if (GetPlatform.isAndroid) {
      var permissionMaidVal = rabbitData.config.permissionMaid;

      maid = permissionMaidVal ? 'True' : 'False';
    } else {
      Permission.appTrackingTransparency.isGranted.then((value) {
        setState(() {
          maid = value ? 'True' : 'False';
        });
      });
    }

    deleteAfterSent = rabbitData.config.deleteAfterSent;
    offlineMode = rabbitData.config.offlineMode;

    retry = rabbitData.config.retryTime;
    retentionDays = rabbitData.config.retentionDays;
    rotationTime = rabbitData.config.rotationTime;
    sessionExpire = rabbitData.config.sessionExpire;
    sessionAutoExpire = rabbitData.config.sessionAutoExpire;

    cpu = rabbitData.config.cpu;
    memory = rabbitData.config.memory;
    bettery = rabbitData.config.batteryLevel;

    _minController.text = rabbitData.config.storageMin.toString();
    _maxController.text = rabbitData.config.storageMax.toString();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
          title: Text('Config'),
          centerTitle: true,
          titleTextStyle: TextStyle(
              fontWeight: FontWeight.bold, fontSize: 24, color: Colors.black),
          actions: [
            IconButton(
                onPressed: () async {
                  _memberIdController.text = Uuid.v4().toString();
                  _ssoIdController.text = Uuid.v4().toString();
                  await rabbitData.setMemberId(_memberIdController.text);
                  await rabbitData.setSsoId(_ssoIdController.text);
                },
                icon: Icon(Icons.restart_alt)),
            IconButton(
                onPressed: () async {
                  await rabbitData.setMemberId(_memberIdController.text);
                  await rabbitData.setSsoId(_ssoIdController.text);

                  rabbitData.setDataCollectionType(collectionType == 'Event'
                      ? DataCollectionType.event
                      : DataCollectionType.rotation);
                  rabbitData.setConsent(consent == 'n/a**'
                      ? null
                      : consent == 'True'
                          ? true
                          : false);
                  rabbitData.setPermissionMaid(maid == 'True' ? true : false);

                  rabbitData.setDeleteAfterSent(deleteAfterSent);
                  rabbitData.setOfflineMode(offlineMode);

                  rabbitData.setRetryOnFailed(retry);
                  rabbitData.setRetentionDays(retentionDays);
                  rabbitData.setRotationTime(rotationTime);
                  rabbitData.setSessionExpire(sessionExpire);
                  rabbitData.setSessionAutoExpire(sessionAutoExpire);

                  rabbitData.setTriggerCondition(
                      cpu: cpu, memory: memory, batteryLevel: bettery);

                  rabbitData.setStorageCondition(
                      min: int.parse(_minController.text),
                      max: int.parse(_maxController.text));

                  // save to stroage data
                  await StorageHelper.saveStroageData(
                      collectionType,
                      consent,
                      maid == 'True' ? true : false,
                      deleteAfterSent,
                      offlineMode,
                      retry,
                      retentionDays,
                      rotationTime,
                      sessionExpire,
                      sessionAutoExpire,
                      cpu,
                      memory,
                      bettery,
                      int.parse(_minController.text),
                      int.parse(_maxController.text));

                  Get.snackbar("Success", "save data success",
                      colorText: Colors.white,
                      backgroundColor: Colors.lightGreen,
                      snackPosition: SnackPosition.TOP,
                      margin:
                          EdgeInsets.symmetric(vertical: 10, horizontal: 10));
                },
                icon: Icon(Icons.save))
          ]),
      body: SingleChildScrollView(
        child: Container(
          padding: EdgeInsets.symmetric(vertical: 10, horizontal: 20),
          child: Column(
            children: [
              TextField(
                controller: _memberIdController,
                decoration: InputDecoration(
                  labelText: 'MemberId',
                  suffixIcon: IconButton(
                    onPressed: _memberIdController.clear,
                    icon: Icon(Icons.clear),
                  ),
                ),
              ),
              SizedBox(height: 20),
              TextField(
                controller: _ssoIdController,
                decoration: InputDecoration(
                  labelText: 'SSO Id',
                  suffixIcon: IconButton(
                    onPressed: _ssoIdController.clear,
                    icon: Icon(Icons.clear),
                  ),
                ),
              ),
              SizedBox(height: 10),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Text('CollectionType'),
                  RadioGroup<String>.builder(
                    direction: Axis.horizontal,
                    groupValue: collectionType,
                    horizontalAlignment: MainAxisAlignment.spaceAround,
                    onChanged: (value) {
                      setState(() => collectionType = value!);
                    },
                    items: _collectionTypeList,
                    textStyle: TextStyle(fontSize: 15, color: Colors.blue),
                    itemBuilder: (item) => RadioButtonBuilder(
                      item,
                    ),
                  )
                ],
              ),
              SizedBox(height: 10),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Text('Consent'),
                  RadioGroup<String>.builder(
                    direction: Axis.horizontal,
                    groupValue: consent,
                    horizontalAlignment: MainAxisAlignment.spaceAround,
                    onChanged: (value) {
                      setState(() => consent = value!);
                    },
                    items: _consentList,
                    textStyle: TextStyle(fontSize: 15, color: Colors.blue),
                    itemBuilder: (item) => RadioButtonBuilder(
                      item,
                    ),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Text('Maid     '),
                  RadioGroup<String>.builder(
                    direction: Axis.horizontal,
                    groupValue: maid,
                    horizontalAlignment: MainAxisAlignment.spaceAround,
                    onChanged: (value) {
                      if (GetPlatform.isIOS) return;
                      setState(() => maid = value!);
                    },
                    items: _maidList,
                    textStyle: TextStyle(
                        fontSize: 15,
                        color: GetPlatform.isIOS ? Colors.grey : Colors.blue),
                    itemBuilder: (item) => RadioButtonBuilder(
                      item,
                    ),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2,
                      fit: FlexFit.tight,
                      child: Text('Delete After Sent')),
                  Flexible(
                      flex: 1,
                      child: Switch(
                          value: deleteAfterSent,
                          onChanged: (value) {
                            setState(() {
                              deleteAfterSent = value;
                            });
                          }))
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2, fit: FlexFit.tight, child: Text('Offline Mode')),
                  Flexible(
                      flex: 1,
                      child: Switch(
                          value: offlineMode,
                          onChanged: (value) {
                            setState(() {
                              offlineMode = value;
                            });
                          }))
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(flex: 2, fit: FlexFit.tight, child: Text('Retry')),
                  Flexible(
                    flex: 1,
                    child: CustomizableCounter(
                        borderColor: Colors.transparent,
                        borderWidth: 0,
                        backgroundColor: Colors.transparent,
                        textColor: Colors.black,
                        textSize: 14,
                        count: retry.toDouble(),
                        step: 1,
                        minCount: 1,
                        showButtonText: false,
                        incrementIcon: const Icon(
                          Icons.add,
                          color: Colors.black,
                          size: 14,
                        ),
                        decrementIcon: const Icon(
                          Icons.remove,
                          color: Colors.black,
                          size: 16,
                        ),
                        onCountChange: (value) {
                          setState(() {
                            retry = value.toInt();
                          });
                        }),
                  ),
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2,
                      fit: FlexFit.tight,
                      child: Text('Retention Days')),
                  Flexible(
                    flex: 1,
                    child: CustomizableCounter(
                        borderColor: Colors.transparent,
                        borderWidth: 0,
                        backgroundColor: Colors.transparent,
                        textColor: Colors.black,
                        textSize: 14,
                        count: retentionDays.toDouble(),
                        step: 1,
                        minCount: 1,
                        showButtonText: false,
                        incrementIcon: const Icon(
                          Icons.add,
                          color: Colors.black,
                          size: 14,
                        ),
                        decrementIcon: const Icon(
                          Icons.remove,
                          color: Colors.black,
                          size: 16,
                        ),
                        onCountChange: (value) {
                          setState(() {
                            retentionDays = value.toInt();
                          });
                        }),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2,
                      fit: FlexFit.tight,
                      child: Text('Rotation Time (Min)')),
                  Flexible(
                    flex: 1,
                    child: CustomizableCounter(
                        borderColor: Colors.transparent,
                        borderWidth: 0,
                        backgroundColor: Colors.transparent,
                        textColor: Colors.black,
                        textSize: 14,
                        count: rotationTime.toDouble(),
                        step: 1,
                        minCount: 1,
                        showButtonText: false,
                        incrementIcon: const Icon(
                          Icons.add,
                          color: Colors.black,
                          size: 14,
                        ),
                        decrementIcon: const Icon(
                          Icons.remove,
                          color: Colors.black,
                          size: 16,
                        ),
                        onCountChange: (value) {
                          setState(() {
                            rotationTime = value.toInt();
                          });
                        }),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2,
                      fit: FlexFit.tight,
                      child: Text('Session Expire (Min)')),
                  Flexible(
                    flex: 1,
                    child: CustomizableCounter(
                        borderColor: Colors.transparent,
                        borderWidth: 0,
                        backgroundColor: Colors.transparent,
                        textColor: Colors.black,
                        textSize: 14,
                        count: sessionExpire.toDouble(),
                        step: 1,
                        minCount: 1,
                        showButtonText: false,
                        incrementIcon: const Icon(
                          Icons.add,
                          color: Colors.black,
                          size: 14,
                        ),
                        decrementIcon: const Icon(
                          Icons.remove,
                          color: Colors.black,
                          size: 16,
                        ),
                        onCountChange: (value) {
                          setState(() {
                            sessionExpire = value.toInt();
                          });
                        }),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Flexible(
                      flex: 2,
                      fit: FlexFit.tight,
                      child: Text('Session Auto Expire (Min)')),
                  Flexible(
                    flex: 1,
                    child: CustomizableCounter(
                        borderColor: Colors.transparent,
                        borderWidth: 0,
                        backgroundColor: Colors.transparent,
                        textColor: Colors.black,
                        textSize: 14,
                        count: sessionAutoExpire.toDouble(),
                        step: 1,
                        minCount: 1,
                        showButtonText: false,
                        incrementIcon: const Icon(
                          Icons.add,
                          color: Colors.black,
                          size: 14,
                        ),
                        decrementIcon: const Icon(
                          Icons.remove,
                          color: Colors.black,
                          size: 16,
                        ),
                        onCountChange: (value) {
                          setState(() {
                            sessionAutoExpire = value.toInt();
                          });
                        }),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  SizedBox(width: 115, child: Text('Cpu $cpu %')),
                  Expanded(
                    child: SfSlider(
                      min: 0,
                      max: 100,
                      value: cpu,
                      stepSize: 1,
                      enableTooltip: true,
                      onChanged: (dynamic value) {
                        setState(() {
                          cpu = value.toInt();
                        });
                      },
                    ),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  SizedBox(width: 115, child: Text('Memory $memory %')),
                  Expanded(
                    child: SfSlider(
                      min: 0,
                      max: 100,
                      value: memory,
                      stepSize: 1,
                      enableTooltip: true,
                      onChanged: (dynamic value) {
                        setState(() {
                          memory = value.toInt();
                        });
                      },
                    ),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  SizedBox(width: 115, child: Text('Battery $bettery %')),
                  Expanded(
                    child: SfSlider(
                      min: 0,
                      max: 100,
                      value: bettery,
                      stepSize: 1,
                      enableTooltip: true,
                      onChanged: (dynamic value) {
                        setState(() {
                          bettery = value.toInt();
                        });
                      },
                    ),
                  )
                ],
              ),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Text('Storage Min (MB) '),
                  Expanded(
                      child: TextField(
                    controller: _minController,
                    keyboardType: TextInputType.number,
                    inputFormatters: <TextInputFormatter>[
                      FilteringTextInputFormatter.digitsOnly
                    ],
                    decoration: InputDecoration(
                      suffixIcon: IconButton(
                        onPressed: _minController.clear,
                        icon: Icon(Icons.clear),
                      ),
                    ),
                  ))
                ],
              ),
              SizedBox(height: 10),
              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  Text('Storage Max (MB) '),
                  Expanded(
                      child: TextField(
                    controller: _maxController,
                    keyboardType: TextInputType.number,
                    inputFormatters: <TextInputFormatter>[
                      FilteringTextInputFormatter.digitsOnly
                    ],
                    decoration: InputDecoration(
                      suffixIcon: IconButton(
                        onPressed: _maxController.clear,
                        icon: Icon(Icons.clear),
                      ),
                    ),
                  ))
                ],
              )
            ],
          ),
        ),
      ),
    );
  }
}
