import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/material.dart';
import 'package:rdc_flutter_sdk/src/constants/app_constants.dart';
import 'package:rdc_flutter_sdk/src/util/advertising_helper.dart';
import 'package:realm/realm.dart';
import 'package:shared_preferences/shared_preferences.dart';

class DeviceInfoController {
  var osType = '';
  var osVersion = '';

  var globalId = '';

  var device = '';
  var model = '';
  var brandName = '';
  var board = '';
  var display = '';

  var maId = '';

  Future<DeviceInfoController> init() async {
    await _getDeviceInfo();
    await getAdvertising();
    return this;
  }

  Future<void> _getDeviceInfo() async {
    try {
      var deviceInfoPlugin = DeviceInfoPlugin();
      var deviceInfo = await deviceInfoPlugin.deviceInfo;
      if (deviceInfo is AndroidDeviceInfo) {
        final sharedPreference = await SharedPreferences.getInstance();
        if (!sharedPreference.containsKey('rdc_globalId')) {
          globalId = Uuid.v4().toString();
          await sharedPreference.setString('rdc_globalId', globalId);
        } else {
          globalId = sharedPreference.getString('rdc_globalId')!;
        }

        osType = osTypeAndroid;
        osVersion = (deviceInfo.version.release ?? 0).toString();
        device = deviceInfo.device ?? '';
        model = deviceInfo.model ?? '';
        brandName = deviceInfo.brand ?? '';
        board = deviceInfo.board ?? '';
      } else if (deviceInfo is IosDeviceInfo) {
        globalId = deviceInfo.identifierForVendor ?? '';
        osType = osTypeIOS;
        osVersion = deviceInfo.systemVersion ?? '';
        device = deviceInfo.model ?? '';
        model = deviceInfo.localizedModel ?? '';
        brandName = 'Apple';
      }
      display =
          '${WidgetsBinding.instance.window.physicalSize.width.toInt()}x${WidgetsBinding.instance.window.physicalSize.height.toInt()}';
    } catch (e) {
      //print(e.toString());
    }
  }

  Future<void> getAdvertising() async {
    try {
      maId = await AdvertisingHelper.getAdvertisingId();
    } catch (e) {
      //print(e.toString());
    }
  }
}
