import 'dart:core';

import 'package:get/utils.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';

class RabbitConfigController {
  late String apiKey;
  late String encryptKey;
  late String collectionType;
  late int retentionDays;
  late int rotationTime;
  late int retryTime;
  late bool deleteAfterSent;
  late int cpu;
  late int memory;
  late int batteryLevel;
  late String dbType;
  late int sessionExpire;
  late int sessionAutoExpire;
  late bool offlineMode;
  late bool? consent;
  late bool permissionMaid;
  late int storageMin;
  late int storageMax;

  RabbitConfigController(RabbitDataConfig rdc) {
    apiKey = rdc.apiKey;
    encryptKey = rdc.encryptKey;
    collectionType = rdc.collectionType.name;
    retentionDays = rdc.retentionDays;
    rotationTime = rdc.rotationTime;
    retryTime = rdc.retryTime;
    deleteAfterSent = rdc.deleteAfterSent;
    cpu = rdc.cpu;
    memory = rdc.memory;
    batteryLevel = rdc.batteryLevel;
    dbType = rdc.dbType.name;
    sessionExpire = rdc.sessionExpire;
    sessionAutoExpire = rdc.sessionAutoExpire;
    offlineMode = rdc.offlineMode;

    consent = rdc.consent;
    if (GetPlatform.isIOS) {
      permissionMaid = false;
      Permission.appTrackingTransparency.isGranted
          .then((value) => permissionMaid = value);
    } else if (GetPlatform.isAndroid) {
      permissionMaid = rdc.permissionMaid;
    }

    storageMin = rdc.storageMin;
    storageMax = rdc.storageMax;
  }
}
