import 'package:hive/hive.dart';
import 'package:realm/realm.dart';

abstract class HiveDBInterface {
  Future<Box<T>> hiveBox<T>(String boxName);
  Future<Map<int, T>> getAll<T>(String boxName);
  Future<Map<int, T?>> get<T>(String boxName, int key);
  Future<void> insert<T>(String boxName, T data);
  Future<void> insertAll<T>(String boxName, List<T> data);
  Future<void> upsert<T>(String boxName, int key, T data);
  Future<void> delete<T>(String boxName, int key);
  Future<void> deleteKeys<T>(String boxName, List<int> keys);
  Future<void> deleteAll<T>(String boxName);
}

abstract class RealmDBInterface {
  late Realm db;
  List<T> getAll<T extends RealmObject>();
  T? get<T extends RealmObject>(int id);
  bool insert<T extends RealmObject>(T data);
  bool insertAll<T extends RealmObject>(List<T> data);
  bool edit<T extends RealmObject>(int id, T data);
  void delete<T extends RealmObject>(T data);
  void deleteAll<T extends RealmObject>();
}
