import 'dart:io';

import 'package:path_provider/path_provider.dart';
import 'package:rdc_flutter_sdk/src/database/db_interface.dart';
import 'package:rdc_flutter_sdk/src/model/realm/rabbit_request_realm.dart';
import 'package:realm/realm.dart';

class RealmDBImpl implements RealmDBInterface {
  @override
  late Realm db;

  Future<RealmDBImpl> init() async {
    Directory appDocDir = await getApplicationDocumentsDirectory();
    final realmDirectory = '${appDocDir.path}/mongodb-realm';
    if (!Directory(realmDirectory).existsSync()) {
      await Directory(realmDirectory).create(recursive: true);
    }

    var config = Configuration.local([RabbitRequestRealm.schema],
        path: '$realmDirectory/rdc_flutter_sdk.realm');
    db = Realm(config);
    return this;
  }

  @override
  List<T> getAll<T extends RealmObject>() {
    var results = db.all<T>();
    return results.toList();
  }

  @override
  T? get<T extends RealmObject>(int id) {
    var result = db.find<T>(id);
    return result;
  }

  @override
  bool insert<T extends RealmObject>(T data) {
    db.write(() => db.add<T>(data));
    return true;
  }

  @override
  bool insertAll<T extends RealmObject>(List<T> data) {
    db.write(() => db.addAll<T>(data));
    return true;
  }

  @override
  bool edit<T extends RealmObject>(int id, T data) {
    var item = db.find<T>(id);
    if (item == null) return false;
    db.write(() {
      item = data;
    });

    return true;
  }

  @override
  void delete<T extends RealmObject>(T data) {
    db.write(() => db.delete<T>(data));
  }

  @override
  void deleteAll<T extends RealmObject>() {
    db.write(() => db.deleteAll<T>());
  }
}
